@@ -150,7 +150,7 @@ class StudentGenerator:
             "gender",
             "highest_degree_earned",
             "country_iso2",
-            "completed_quiz",
+            "admissions_quiz",
         ]
         if self.is_experiment:
             cols.pop(-1)
