@@ -1,5 +1,6 @@
-from typing import Union
+from typing import Optional, Union
 
+import pandas as pd
 from pymongo import MongoClient
 
 from teaching_tools.ab_test.data_model import Cohort
@@ -12,8 +13,9 @@ from teaching_tools.ab_test.repository import (
 class Experiment:
     """Class to generate experimental student data and insert into repository."""
 
-    def __init__(self, repo: AbstractRepository) -> None:
+    def __init__(self, repo: AbstractRepository, collection: str) -> None:
         self.attach_repository(repo)
+        self.collection = collection
 
     def attach_repository(
         self,
@@ -42,7 +44,7 @@ class Experiment:
             raise Exception("Cannot attach repository.")
 
     def add_cohort_to_repository(
-        self, collection="ds_applicants", overwrite=False, confirm_msg=True
+        self, overwrite=False, confirm_msg=True
     ) -> None:
         """Add cohort of students to repository.
 
@@ -55,9 +57,11 @@ class Experiment:
         confirm_msg : bool, optional
             Whether to print confirmation message, by default True
         """
-        self.repo.create_collection(collection, overwrite=overwrite)
+        self.repo.create_collection(
+            collection=self.collection, overwrite=overwrite
+        )
         r = self.repo.insert(
-            collection,
+            self.collection,
             records=self.cohort.yield_students(),
             return_result=True,
         )
@@ -71,7 +75,7 @@ class Experiment:
                     f"Failed to add {len(self.cohort._students)} students to repository."
                 )
 
-    def run_experiment(self, days: int) -> None:
+    def run_experiment(self, days: int, start: Optional[str] = None) -> None:
         """Add experimental student data to repository.
 
         Parameters
@@ -79,7 +83,9 @@ class Experiment:
         days : int
             Number of days to run the experiment. More days means more students.
         """
-        self.cohort = Cohort(days=days, is_experiment=True)
+        if start is None:
+            start = pd.Timestamp.now()
+        self.cohort = Cohort(days=days, start=start, is_experiment=True)
         self.add_cohort_to_repository()
 
     def reset_experiment(self, confirm_msg=True) -> None:
@@ -91,7 +97,7 @@ class Experiment:
             Whether to print confirmation message, by default True
         """
         results = self.repo.drop(
-            collection="ds_applicants",
+            collection=self.collection,
             query={"in_experiment": True},
             return_result=True,
         )
