@@ -59,9 +59,9 @@ cohort_params = {
             "74": 4.521817770743839e-05,
             "76": 4.521817770743839e-05,
         },
-        "completed_quiz": {
-            False: 0.2622654307031427,
-            True: 0.7377345692968573,
+        "admissions_quiz": {
+            "incomplete": 0.2622654307031427,
+            "complete": 0.7377345692968573,
         },
         "country_iso2": {
             "AD": 9.044044496698923e-05,
@@ -262,10 +262,10 @@ cohort_params = {
         },
     },
     "experiment": {
-        "response_var": "completed_quiz",
+        "response_var": "admissions_quiz",
         "contingency_table": {
-            "control": {True: 0.1, False: 0.4},
-            "treatment": {True: 0.2, False: 0.3},
+            "email": {"complete": 0.2, "incomplete": 0.3},
+            "no email": {"complete": 0.1, "incomplete": 0.4},
         },
     },
     "daily_traffic": {"mu": 165, "sigma": 31},
